@@ -6,7 +6,7 @@ use Carp;
 use base 'Geo::GDAL::FFI::Object';
 use Scalar::Util qw /blessed/;
 
-our $VERSION = 0.0700;
+our $VERSION = 0.0800;
 
 sub DESTROY {
     my $self = shift;
@@ -92,11 +92,23 @@ sub GetBands {
     return @bands;
 }
 
+sub GetLayerCount {
+    my ($self) = @_;
+    return Geo::GDAL::FFI::GDALDatasetGetLayerCount($$self);
+}
+
+
 sub GetLayer {
     my ($self, $i) = @_;
     $i //= 0;
-    my $l = Geo::GDAL::FFI::isint($i) ? Geo::GDAL::FFI::GDALDatasetGetLayer($$self, $i) :
-    Geo::GDAL::FFI::GDALDatasetGetLayerByName($$self, $i);
+    my $l = Geo::GDAL::FFI::isint($i)
+      ? Geo::GDAL::FFI::GDALDatasetGetLayer($$self, $i)
+      : Geo::GDAL::FFI::GDALDatasetGetLayerByName($$self, $i);
+    unless ($l) {
+        my $msg = Geo::GDAL::FFI::error_msg()
+          // "Could not access layer $i in data set.";
+        confess $msg if $msg;
+    }
     Geo::GDAL::FFI::_register_parent_ref ($l, $self);
     return bless \$l, 'Geo::GDAL::FFI::Layer';
 }
@@ -106,16 +118,16 @@ sub CreateLayer {
     $args //= {};
     my $name = $args->{Name} // '';
     my ($gt, $sr);
-    if (exists $args->{GeometryFields}) {
+    if ($args->{GeometryFields}) {
         $gt = $Geo::GDAL::FFI::geometry_types{None};
     } else {
         $gt = $args->{GeometryType} // 'Unknown';
         $gt = $Geo::GDAL::FFI::geometry_types{$gt};
         confess "Unknown geometry type: '$args->{GeometryType}'." unless defined $gt;
-        $sr = Geo::GDAL::FFI::OSRClone(${$args->{SpatialReference}}) if exists $args->{SpatialReference};
+        $sr = Geo::GDAL::FFI::OSRClone(${$args->{SpatialReference}}) if $args->{SpatialReference};
     }
     my $o = 0;
-    if (exists $args->{Options}) {
+    if ($args->{Options}) {
         for my $key (keys %{$args->{Options}}) {
             $o = Geo::GDAL::FFI::CSLAddString($o, "$key=$args->{Options}->{$key}");
         }
@@ -127,12 +139,12 @@ sub CreateLayer {
     confess $msg if $msg;
     Geo::GDAL::FFI::_register_parent_ref ($l, $self);
     my $layer = bless \$l, 'Geo::GDAL::FFI::Layer';
-    if (exists $args->{Fields}) {
+    if ($args->{Fields}) {
         for my $f (@{$args->{Fields}}) {
             $layer->CreateField($f);
         }
     }
-    if (exists $args->{GeometryFields}) {
+    if ($args->{GeometryFields}) {
         for my $f (@{$args->{GeometryFields}}) {
             $layer->CreateGeomField($f);
         }
@@ -504,6 +516,10 @@ SpatialReference are ignored.
 
 =back
 
+=head2 GetLayerCount
+ my $count = $dataset->GetLayerCount();
+
+
 =head2 GetLayer
 
  my $layer = $dataset->GetLayer($name);
