@@ -4,19 +4,19 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = 0.0700;
+our $VERSION = 0.0800;
 
 sub new {
     my ($class, $args) = @_;
     $args //= {};
     my $name = $args->{Name} // '';
     my $self = bless \Geo::GDAL::FFI::OGR_FD_Create($name), $class;
-    if (exists $args->{Fields}) {
+    if ($args->{Fields}) {
         for my $field (@{$args->{Fields}}) {
             $self->AddField(Geo::GDAL::FFI::FieldDefn->new($field));
         }
     }
-    if (exists $args->{GeometryFields}) {
+    if ($args->{GeometryFields}) {
         my $first = 1;
         for my $field (@{$args->{GeometryFields}}) {
             if ($first) {
